# brainview Development information

This document is intended for developers who work on `brainview`. Users should ignore this file and install a release via `pip` instead. See the [README file in the repo root](../README.md) for details.

While `brainview` works on several platforms, development happens under Ubuntu Linux 18.04. I also work on brainview under MacOS High Sierra sometimes, but there I use Anaconda (and I do not describe the setup in this file).

## Essential tools

You will need Python and some standard development tools. You will also need a working matplotlib including a proper backend. I went for qt. Under a Debian-based Linux distro, this should be enough:

```console
sudo apt-get install python-pip build-essential git python-pyqt5 python-pyqt5.qtsvg
```

You will also need Python bindings for qt. You should install them in the virtual environment using `pip`, see below.


## Development installation (Linux, pip)

It is recommended to use a virtual environment for hacking on `brainview`. First, clone the repo:

```console
mkdir ~/develop/          # replace this dir with whatever you like or use an existing directory where you store all your code or projects.
cd ~/develop
git clone https://github.com/dfsp-spirit/brainview
cd brainview/             # we will refer to this directory as the `repository root` or `repo root` throughout this document.
```

Now let's prepare the dev environment. In the repo root:

```console
pip install --user virtualenv      # unless you already have it
python -m virtualenv env/          # creates a virtual python environment in the new directory `env/` in the repo root, i.e., `~/develop/brainview/env/` in our example
```


Note: Once you have created the virtual environment, all you have to do is use it. The first thing we'll do is install the Python bindings for qt I mentioned earlier:
```console
cd ~/develop/brainview             # replace with your repo root
source env/bin/activate            # to activate the virtual environment

pip install pyside2                # install qt bindings, feel free to use another backend and its bindings
some_other_command...              

deactivate                         # to leave it
```

Ensure that you are still in the repo root, then activate the virtual environment and install `brainview` in development mode:

```console
source env/bin/activate
pip install --editable .           # installs brainview from the current directory, and grabs its dependencies from PyPI (including [brainload](https://github.com/dfsp-spirit/brainload))
```

You can now use the `brainview` module by typing `import brainload` in your python application or an interactive python session. Changes you make to the module source are applied automatically.

## Development under MacOS (conda + pip)

I ended up using `conda`. Install conda and follow the Linux instructions above to get the repo. Then:

```console
conda create -y --name brainview python=2.7
conda activate brainview
conda install -y matplotlib mayavi brainload
pip install --editable .
```

## Tests

Tests and test data are not shipped in the releases. Follow the installation instructions for the development version if you want to run them. Once you have done that, continue from here.

### Running the tests locally

#### Obtaining the test data

Not all data is included with the repo, as the test data is quite large and some fake subjects are generated by copying others. The good news is that you can get all test data by running a single shell script from the repo root:

```console
cd ~/develop/brainview               # replace with your repo root
./develop/get_test_data_all.bash
```

The script downloads all required [neuroimaging test data from Github](https://github.com/dfsp-spirit/neuroimaging_testdata). If you have a properly configured local installation of FreeSurfer (with environment variable `FREESURFER_HOME` pointing to the installation directory), it will prefer that for some data.

#### Running the tests

Uuse the test integration into `setup.py`, as this will install all test dependencies for you automatically. In the virtual environment and the top-level brainview directory, just run:

```console
python setup.py test
```

#### Test coverage

Test coverage statistics are displayed automatically when running the tests as described above. To see the coverage line by line, run `coverage html` and then open `htmlcov/index.html` in your favorite browser.


### Continuous Integration

The tests are run automatically when you push to master and devs get results by email. Build status from travis-ci.org (Linux, branch master):

[![Build Status](https://travis-ci.org/dfsp-spirit/brainview.svg?branch=master)](https://travis-ci.org/dfsp-spirit/brainview)


## Packaging


### Building the `brainview` documentation

We use sphinx with the theme from `readthedocs.org` to generate the documentation. In the virtual environment:

```console
pip install sphinx sphinx_rtd_theme
cd doc/
make html
```

This will build the documentation in HTML format and place it in `_build/html/` (relative to the `doc/` directory).

We will put the documentation online later (maybe on a GitHub page), but that does not make any sense yet.

Note that if you added new modules in separate directories, for the documentation to show up,
you will have to tell autodoc about the paths to the new directories by adding them to `sys.path`
at the top of the `doc/conf.py` file.
